<TS language="hr" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Dodajte novu adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopiraj trenutno odabranu adresu u međuspremnik</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiraj</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Brisanje trenutno odabrane adrese s popisa.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Iz&amp;briši</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopirati &amp;oznaku</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Izmjeniti</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez oznake)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dijalog lozinke</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Unesite lozinku</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova lozinka</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ponovite novu lozinku</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Šifriranje nov?anika</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ova operacija treba lozinku vašeg nov?anika kako bi se nov?anik otklju?ao.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Otklju?aj nov?anik</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Promjena lozinke</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Unesite staru i novu lozinku za nov?anik.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Potvrdi šifriranje nov?anika</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Jeste li sigurni da želite šifrirati svoj nov?anik?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Nov?anik šifriran</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Šifriranje nov?anika nije uspjelo</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Šifriranje nov?anika nije uspjelo zbog interne pogreške. Vaš nov?anik nije šifriran.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Priložene lozinke se ne podudaraju.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Otklju?avanje nov?anika nije uspjelo</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Lozinka za dešifriranje nov?anika nije to?na.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Lozinka nov?anika je uspješno promijenjena.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Upozorenje: Tipka Caps Lock je uklju?ena!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Novčanik</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Pregled</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Prikaži opći pregled novčanika</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Pošalji</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>Pri&amp;mi</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Pretraži povijest transakcija</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Izlaz</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Izlazak iz programa</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Pos&amp;tavke...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Po&amp;kaži / Sakrij</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Ši&amp;friraj novčanik...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Promjena &amp;lozinke...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Promijenite lozinku za šifriranje novčanika</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>P&amp;otpišite poruku...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Potvrdite poruku...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Konzola za dijagnostiku</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Otvori konzolu za dijagnostiku</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datoteka</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Postavke</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Ažurno</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Ažuriranje...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Poslana transakcija</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Dolazna transakcija</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Novčanik je &lt;b&gt;šifriran&lt;/b&gt; i trenutno &lt;b&gt;zaključan&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtova:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Vraćeno:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Broj potvrda</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrđeno</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopirati adresu</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopirati oznaku</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj iznos</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez oznake)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Uredi adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Oznaka</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nova adresa za primanje</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nova adresa za slanje</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Uredi adresu za primanje</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Uredi adresu za slanje</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Upisana adresa "%1" je ve? u adresaru.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Ne mogu otklju?ati nov?anik.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Stvaranje novog klju?a nije uspjelo.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Glavno</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Mreža</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapiraj port koristeći &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Vrata:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Proxy vrata (npr. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimizirati umjesto iza?i iz aplikacije kada je prozor zatvoren. Kada je ova opcija omogu?ena, aplikacija ?e biti zatvorena tek nakon odabira Izlaz u izborniku.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Prikaži adrese u popisu transakcija</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Prozor</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Prikaži samo ikonu u sistemskoj traci nakon minimiziranja prozora</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimiziraj u sistemsku traku umjesto u traku programa</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimiziraj kod zatvaranja</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Prikaz</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Jezi&amp;k sučelja:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Jedinica za prikaz iznosa:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Izaberite željeni najmanji dio bitcoina koji će biti prikazan u sučelju i koji će se koristiti za plaćanje.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;U redu</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Odustani</translation>
    </message>
    <message>
        <source>default</source>
        <translation>standardne vrijednosti</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Priložena proxy adresa je nevažeća.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Oblik</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Ukupno:</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Verzija klijenta</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informacije</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Broj veza</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Lanac blokova</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Trenutni broj blokova</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Posljednje vrijeme bloka</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Otvori</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konzola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Mrežni promet</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Ukupno:</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Očisti konzolu</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Procjenjeni ukupni broj blokova</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Ime klijenta</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Koristite tipke gore i dolje za izbor već korištenih naredbi. &lt;b&gt;Ctrl-L&lt;/b&gt; kako bi očistili ekran i povijest naredbi.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Slanje novca</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Nedovoljna sredstva</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtova:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Pošalji novce većem broju primatelja u jednoj transakciji</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;Dodaj primatelja</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Obriši &amp;sve</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Potvrdi akciju slanja</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Pošalji</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj iznos</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Potvrdi slanje novca</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Adresa primatelja je nevaljala, molimo provjerite je ponovo.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Iznos mora biti ve?i od 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Iznos je ve?i od stanja ra?una.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Iznos je ve?i od stanja ra?una kad se doda naknada za transakcije od %1.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Pronašli smo adresu koja se ponavlja. U svakom pla?anju program može svaku adresu koristiti samo jedanput.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez oznake)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Iznos:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Primatelj plaćanja:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Poruka:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Oznaka:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Zalijepi adresu iz međuspremnika</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Unesite oznaku za ovu adresu kako bi ju dodali u vaš adresar</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Potpišite poruku</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Možete potpisati poruke sa svojom adresom kako bi dokazali da ih posjedujete. Budite oprezni da ne potpisujete ništa mutno, jer bi vas phishing napadi mogli na prevaru natjerati da prepišete svoj identitet njima. Potpisujte samo detaljno objašnjene izjave sa kojima se slažete.</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Zalijepi adresu iz međuspremnika</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Upišite poruku koju želite potpisati ovdje</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>&amp;Potpišite poruku</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Obriši &amp;sve</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Potvrdite poruku</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Otklju?avanje nov?anika je otkazano.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Poruka je potpisana.</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Otvoren do %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1 nije dostupan</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/nepotvr?eno</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 potvrda</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, još nije bio uspješno emitiran</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Izvor</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nepoznato</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Za</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>vlastita adresa</translation>
    </message>
    <message>
        <source>label</source>
        <translation>oznaka</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Upla?eno</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>Nije prihva?eno</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Zaduženje</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Naknada za transakciju</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Neto iznos</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Poruka</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komentar</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detalji transakcije</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Ovaj prozor prikazuje detaljni opis transakcije</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tip</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Otvoren do %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Potvr?en (%1 potvrda)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generirano, ali nije prihva?eno</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Primljeno s</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Primljeno od</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Poslano za</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pla?anje samom sebi</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(n/d)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Status transakcije</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Datum i vrijeme kad je transakcija primljena</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Vrsta transakcije.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Odredište transakcije</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Iznos odbijen od ili dodan k saldu.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Danas</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Ovaj tjedan</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Ovaj mjesec</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Prošli mjesec</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Ove godine</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Raspon...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Primljeno s</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Poslano za</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Tebi</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Rudareno</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostalo</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Min iznos</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopirati adresu</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopirati oznaku</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj iznos</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Izmjeniti oznaku</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvr?eno</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tip</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Iznos</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Raspon:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>za</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Usage:</source>
        <translation>Upotreba:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Prikaži komande</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Potraži pomo? za komandu</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Upozorenje: -paytxfee je podešen na preveliki iznos.  To je iznos koji ?ete platiti za obradu transakcije.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Nevaljali iznos za opciju -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Nevaljala -proxy adresa: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Greška kod u?itavanja wallet.dat: Nov?anik pokvaren</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Greška kod u?itavanja wallet.dat</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Učitavanje adresa...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Program ne može koristiti %s na ovom ra?unalu (bind returned error %d, %s)</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Nevaljali iznos za opciju</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nedovoljna sredstva</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Učitavanje indeksa blokova...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Učitavanje novčanika...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Nije moguće upisati zadanu adresu.</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ponovno pretraživanje...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Učitavanje gotovo</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
</context>
</TS>